@@ -265,16 +265,16 @@ def fatal(*tokens: Token, exit_code: int = 1, **kwargs: Any) -> None:
 
 def error(*tokens: Token, **kwargs: Any) -> None:
     """Print an error message"""
-    tokens = [bold, red, "Error:"] + list(tokens)  # type: ignore
+    args = [bold, red, "Error:"] + list(tokens)
     kwargs["fileobj"] = sys.stderr
-    message(*tokens, **kwargs)
+    message(*args, **kwargs)
 
 
 def warning(*tokens: Token, **kwargs: Any) -> None:
     """Print a warning message"""
-    tokens = [brown, "Warning:"] + list(tokens)  # type: ignore
+    args = [brown, "Warning:"] + list(tokens)
     kwargs["fileobj"] = sys.stderr
-    message(*tokens, **kwargs)
+    message(*args, **kwargs)
 
 
 def info(*tokens: Token, **kwargs: Any) -> None:
@@ -435,7 +435,7 @@ def message_for_exception(exception: Exception, message: str) -> Sequence[Token]
     """
     tb = sys.exc_info()[2]
     buffer = io.StringIO()
-    traceback.print_tb(tb, file=io)  # type: ignore
+    traceback.print_tb(tb, file=buffer)
     # fmt: off
     return (
         red, message + "\n",
